# yogaflo

![Build](https://github.com/strawberry-jam-cabal/yogaflo/workflows/Build/badge.svg)

This package generates random yoga flows using a markov model

## Installation

```
pip install yogaflo
```
Requires Python 3.6 or greater.


## Usage

```
yogaflo
```

or

```
python3 -m yogaflo
```
